package es.uca.xmleye.gui.util;

/*
 Copyright (C) 2005-2008 Antonio García Domínguez

 This program is free software; you can redistribute it 
 and/or modify it under the terms of the GNU General Public 
 License as published by the Free Software Foundation; 
 either version 2 of the License, or (at your option) any 
 later version.

 This program is distributed in the hope that it will be 
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE. See the GNU General Public License for more 
 details.

 You should have received a copy of the GNU General Public 
 License along with this program; if not, write to the Free 
 Software Foundation, Inc., 59 Temple Place, Suite 330, 
 Boston, MA 02111-1307 USA
 */

import javax.swing.AbstractAction;
import java.util.ResourceBundle;
import javax.swing.ImageIcon;
import javax.swing.KeyStroke;
import java.util.MissingResourceException;

/**
 * <p>
 * Acción que toma sus elementos del ResourceBundle disponible directamente.
 * </p>
 * 
 * <p>
 * Evita código sucio y repetitivo en la construcción de elementos que se
 * comparten entre la barra de herramientas y la barra de menús.
 * </p>
 * 
 * <p>
 * El esquema de nombrado de los atributos debe ser:
 * </p>
 * <ul>
 * <li><b><code>id</code>:</b>Nombre de la acción.</li>
 * <li><b><code>id_d</code></b>: Descripción.</li>
 * <li><b><code>id_m</code></b>: Mnemónico (Integer).</li>
 * <li><b><code>id_a</code></b>: Acelerador (KeyStroke, opcional).</li>
 * </ul>
 */
public abstract class AccionResource extends AbstractAction {
	public AccionResource(ResourceBundle res, String id) {
		super(res.getString(id));
		preparar(res, id);
	}

	public AccionResource(ResourceBundle res, String id, String ruta) {
		super(res.getString(id), new ImageIcon(ruta));
		preparar(res, id);
	}

	private void preparar(ResourceBundle res, String id) {
		putValue(SHORT_DESCRIPTION, res.getString(id + "_d"));
		putValue(MNEMONIC_KEY, (Integer) res.getObject(id + "_m"));

		try {
			putValue(ACCELERATOR_KEY, (KeyStroke) res.getObject(id + "_a"));
		} catch (MissingResourceException ex) {
		}
	}
}
