package es.uca.xmleye.gui.arboles;

/*
  Copyright (C) 2005-2008 Antonio García Domínguez
  
  This program is free software; you can redistribute it 
  and/or modify it under the terms of the GNU General Public 
  License as published by the Free Software Foundation; 
  either version 2 of the License, or (at your option) any 
  later version.
  
  This program is distributed in the hope that it will be 
  useful, but WITHOUT ANY WARRANTY; without even the implied 
  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
  PURPOSE. See the GNU General Public License for more 
  details.
  
  You should have received a copy of the GNU General Public 
  License along with this program; if not, write to the Free 
  Software Foundation, Inc., 59 Temple Place, Suite 330, 
  Boston, MA 02111-1307 USA
*/

import junit.framework.*;
import junit.textui.*;

import org.w3c.dom.*;
import javax.xml.parsers.*;
import org.xml.sax.*;

import es.uca.xmleye.gui.arboles.ModArbolDOM;
import es.uca.xmleye.gui.arboles.ModArbolDirigidoDatos;

import java.io.*;
import static es.uca.xmleye.gui.arboles.ModArbolDirigidoDatos.*;

/** 
    Pruebas de unidad de la clase ModArbolDirigidoDatos.
*/
public class PruebaModArbolDirigidoDatos extends TestCase 
{
  private Document _docXML;
  private ModArbolDirigidoDatos _model;
  private ModArbolDOM _modelDOM;

  /** Crea una nueva colección de casos de prueba. */
  public PruebaModArbolDirigidoDatos(String nombre) 
  {
    super(nombre);
  }
  
  /** 
      Comprueba que no se puede acceder a ningún nodo con
      <code>ATRIBUTO_OCULTO == VALOR_ACTIVO</code>.
  */
  public void testNodosOcultos() 
  {
    for (IteradorPreorden it = new IteradorPreorden(_model);
	 it.hasNext(); ) {

      final Element elem = (Element)it.next();
      assertTrue(!VALOR_ACTIVO.equals(elem.getAttribute(ATRIBUTO_OCULTO)));
    }
  }

  /** 
      Comprueba que, según el modelo, todo nodo tal que
      <code>ATRIBUTO_HOJA == VALOR_ACTIVO</code> tiene siempre 0
      hijos, y se comporte como tal: no habrá forma de obtener hijos
      de él, ni de saber el índice de ninguno de sus hijos (aunque lo
      fueran en el modelo DOM original).
  */
  public void testNodosHoja()
  {
    for (IteradorPreorden it = new IteradorPreorden(_model);
	 it.hasNext(); ) {
      final Element elem = (Element)it.next();
      if (VALOR_ACTIVO.equals(elem.getAttribute(ATRIBUTO_HOJA))) {
	assertTrue(_model.getChildCount(elem) == 0);

	// Los hijos no deben ser accesibles de _ninguna_ forma
	assertTrue(_model.getChild(elem,0) == null);

	Node primerHijoDOM = (Node)_modelDOM.getChild(elem, 0);
	if (primerHijoDOM != null) {
	  assertTrue(_model.getIndexOfChild(elem, primerHijoDOM) == -1);
	}
      }
    }
  }

  /** Crea el conjunto de casos de prueba para JUnit. */
  public static Test suite() 
  {
    return new TestSuite(PruebaModArbolDirigidoDatos.class);
  }

  /** Ejecuta mediante JUnit los casos de prueba. */
  public static void main(String[] args) 
  {
    TestRunner.run(suite());
  }

  /** 
      Preparación: carga un documento XML ya definido.
  */
  protected void setUp() throws ParserConfigurationException, SAXException, 
                                FileNotFoundException, IOException
  {
      DocumentBuilder dBuilder = 
	DocumentBuilderFactory.newInstance().newDocumentBuilder();

      final FileInputStream fIS = 
	new FileInputStream("build/es/uca/xmleye/gui/arboles/testTree.xml");

      _docXML  = dBuilder.parse(fIS);
      _model = new ModArbolDirigidoDatos(_docXML);
      _modelDOM = new ModArbolDOM(_docXML);
  }

  /** Libera los recursos asociados a las pruebas. */
  protected void tearDown() {
    _model = null;
  }

}
